summaryrefslogtreecommitdiff
path: root/tests/test-auto-summary.sh
diff options
context:
space:
mode:
authorJonathan Lebon <jonathan@jlebon.com>2018-07-30 10:46:58 -0400
committerAtomic Bot <atomic-devel@projectatomic.io>2018-08-01 19:59:07 +0000
commit786ee6bdec8cac24b127af7828659d71702d4f8e (patch)
treef8be4dcf4f316fb4ec9a0a8261517c34f2ba168b /tests/test-auto-summary.sh
parent3e96ec9811b5cfc5481f8b6b06c8d34d9a35408e (diff)
downloadostree-786ee6bdec8cac24b127af7828659d71702d4f8e.tar.gz
lib/config: Rename change-update-summary to auto-...
Mildly bikeshed, though I find the name `auto-update-summary` to be easier to grok than `change-update-summary`. I think it's because it can be read as "verb-verb-noun" rather than "noun-verb-noun". Closes: #1693 Approved by: mwleeds
Diffstat (limited to 'tests/test-auto-summary.sh')
-rwxr-xr-xtests/test-auto-summary.sh6
1 files changed, 3 insertions, 3 deletions
diff --git a/tests/test-auto-summary.sh b/tests/test-auto-summary.sh
index 5811fcde..3a04f184 100755
--- a/tests/test-auto-summary.sh
+++ b/tests/test-auto-summary.sh
@@ -65,7 +65,7 @@ touch repo/summary.sig
$OSTREE summary --update
assert_not_has_file repo/summary.sig
# Check that without change-update-summary set, adding, changing, or deleting a ref doesn't update the summary
$OSTREE summary --update
OLD_MD5=$(md5sum repo/summary)
$OSTREE commit -b test2 -s "A commit" test
@@ -80,8 +80,8 @@ $OSTREE refs --delete test
assert_streq "$OLD_MD5" "$(md5sum repo/summary)"
-# Check that with change-update-summary set, adding, changing, or deleting a ref updates the summary
-$OSTREE --repo=repo config set core.change-update-summary true
+# Check that with auto-update-summary set, adding, changing, or deleting a ref updates the summary
+$OSTREE --repo=repo config set core.auto-update-summary true
$OSTREE summary --update
OLD_MD5=$(md5sum repo/summary)
@@ -65,7 +65,7 @@ touch repo/summary.sig
$OSTREE summary --update
assert_not_has_file repo/summary.sig
-# Check that without change-update-summary set, adding, changing, or deleting a ref doesn't update the summary
+# Check that without auto-update-summary set, adding, changing, or deleting a ref doesn't update the summary
$OSTREE summary --update
OLD_MD5=$(md5sum repo/summary)